@@ -1,6 +1,6 @@
 import datetime
 from python_helper.api.src.domain import Constant as c
-from python_helper.api.src.service import ObjectHelper, StringHelper, RandomHelper, LogHelper
+from python_helper.api.src.service import ObjectHelper, StringHelper, RandomHelper
 
 DEFAULT_DATETIME_PATTERN = '%Y-%m-%d %H:%M:%S'
 DEFAULT_DATE_PATTERN = '%Y-%m-%d'
